from apscheduler.schedulers.background import BackgroundScheduler
import logging
from typing import Dict, Callable
from sqlalchemy.orm import Session
from services.product import ProductService
from db.models import File


class TaskService:
    def __init__(self, db: Session, product_service: ProductService):
        self.scheduler = BackgroundScheduler()
        self.logger = logging.getLogger(__name__)
        self.tasks: Dict[str, Callable] = {}
        self.db = db
        self.product_service = product_service
    
    async def start(self):
        self.scheduler.start()
        self.logger.info("Task scheduler started.")
        self.register_scheduled_tasks()
    
    def register_scheduled_tasks(self):
        self.scheduler.add_job(
            self.daily_report,
            'cron',
            hour=0,
            minute=0,
            id='daily_report'
        )
    
    # Tasks that should be scheduled
    async def daily_report(self):
        self.logger.info("Generating daily report")
        # Daily report logic
    

    async def process_manabox_file(self, file: File):
        self.logger.info("Processing ManaBox file")
        self.product_service.bg_process_manabox_file(file.id)
        self.logger.info("Finished processing ManaBox file")